// src/teeny-conf.ts
import * as fs from "fs";
import * as path from "path";
import atomicWrite from "write-file-atomic";
import has from "lodash.has";
import get from "lodash.get";
import set from "lodash.set";
import unset from "lodash.unset";
import clonedeep from "lodash.clonedeep";
var TeenyConf = class {
  _configPath;
  _defaultConfig;
  _conf;
  constructor(configPath, defaultConfig) {
    if (!configPath)
      throw new TypeError("teenyconf needs a valid configPath");
    this._configPath = path.resolve(configPath);
    this._defaultConfig = defaultConfig;
    if (!fs.existsSync(path.dirname(this._configPath))) {
      fs.mkdirSync(path.dirname(this._configPath));
    }
    try {
      this._conf = JSON.parse(fs.readFileSync(this._configPath).toString());
    } catch (err) {
      this._conf = clonedeep(this._defaultConfig);
      this.save();
    }
  }
  /**
   * Reload the configuration from file
   */
  reload() {
    this._conf = JSON.parse(fs.readFileSync(this._configPath).toString());
  }
  /**
   * Save current config to its associated file
   */
  save(minify = false) {
    const output = minify ? JSON.stringify(this._conf) : JSON.stringify(this._conf, null, " ");
    atomicWrite.sync(this._configPath, output);
  }
  get(key, def) {
    if (key) {
      return get(this._conf, key, def);
    }
    return this._conf;
  }
  getx(key, def) {
    if (key) {
      const valueExists = has(this._conf, key);
      if (valueExists) {
        return get(this._conf, key, def);
      }
    }
    throw new Error(`TeenyConf - key "${key}" does not exist in the config.`);
  }
  /**
   * Set/add key/value pair
   */
  set(key, value) {
    set(this._conf, key, value);
  }
  /**
   * Delete a key from the configuration
   */
  delete(key) {
    unset(this._conf, key);
  }
  /**
   * Clear the configuration and rolls it back the default config
   */
  clear() {
    this._conf = clonedeep(this._defaultConfig);
  }
  /**
   * Check if a key exists
   */
  has(key) {
    return has(this._conf, key);
  }
};
var teeny_conf_default = TeenyConf;
export {
  teeny_conf_default as default
};
//# sourceMappingURL=teeny-conf.js.map